## Allure Pytest Plugin

[Копия проекта allure pytest](https://github.com/allure-framework/allure-python) 

---

## Quick start

```shell
$ pip install allure-pytest-il-il
$ pytest --alluredir=%allure_result_folder% ./tests
$ allure serve %allure_result_folder%
```